@@ -1,5 +1,4 @@
 """Provide the Comment class."""
-from ...const import urljoin
 from ...exceptions import ClientException
 from ..comment_forest import CommentForest
 from .base import RedditBase
@@ -10,8 +9,23 @@ from .redditor import Redditor
 class Comment(RedditBase, InboxableMixin, UserContentMixin):
     """A class that represents a reddit comments."""
 
+    MISSING_COMMENT_MESSAGE = ('This comment does not appear to be in the '
+                               'comment tree')
     STR_FIELD = 'id'
 
+    @staticmethod
+    def id_from_url(url):
+        """Get the ID of a comment from the full URL."""
+        parts = RedditBase._url_parts(url)
+        try:
+            comment_index = parts.index('comments')
+        except ValueError:
+            raise ClientException('Invalid URL: {}'.format(url))
+
+        if len(parts) - 4 != comment_index:
+            raise ClientException('Invalid URL: {}'.format(url))
+        return parts[-1]
+
     @property
     def is_root(self):
         """Return True when the comment is a top level comment."""
@@ -43,27 +57,29 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
     @submission.setter
     def submission(self, submission):
         """Update the Submission associated with the Comment."""
-        assert self.name not in submission._comments_by_id
         submission._comments_by_id[self.name] = self
         self._submission = submission
+        # pylint: disable=not-an-iterable
         for reply in getattr(self, 'replies', []):
             reply.submission = submission
 
     def __init__(self, reddit, id=None,  # pylint: disable=redefined-builtin
-                 _data=None):
+                 url=None, _data=None):
         """Construct an instance of the Comment object."""
-        if bool(id) == bool(_data):
-            raise TypeError('Either `id` or `_data` must be provided.')
+        if [id, url, _data].count(None) != 2:
+            raise TypeError('Exactly one of `id`, `url`, or `_data` must be '
+                            'provided.')
         self._mod = self._replies = self._submission = None
         super(Comment, self).__init__(reddit, _data)
         if id:
             self.id = id  # pylint: disable=invalid-name
+        elif url:
+            self.id = self.id_from_url(url)
         else:
             self._fetched = True
 
     def __setattr__(self, attribute, value):
         """Objectify author, replies, and subreddit."""
-        # pylint: disable=redefined-variable-type
         if attribute == 'author':
             value = Redditor.from_data(self._reddit, value)
         elif attribute == 'replies':
@@ -79,8 +95,7 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
     def _extract_submission_id(self):
         if 'context' in self.__dict__:
             return self.context.rsplit('/', 4)[1]
-        else:
-            return self.link_id.split('_', 1)[1]
+        return self.link_id.split('_', 1)[1]
 
     def parent(self):
         """Return the parent of the comment.
@@ -106,13 +121,38 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
            parent.refresh()
            print(parent.replies)  # Output is at least: [Comment(id='cklhv0f')]
 
+        .. warning:: Successive calls to :meth:`.parent()` may result in a
+           network request per call when the comment is not obtained through a
+           :class:`.Submission`. See below for an example of how to minimize
+           requests.
+
+        If you have a deeply nested comment and wish to most efficiently
+        discover its top-most :class:`.Comment` ancestor you can chain
+        successive calls to :meth:`.parent()` with calls to :meth:`.refresh()`
+        at every 9 levels. For example:
+
+        .. code:: python
+
+           comment = reddit.comment('dkk4qjd')
+           ancestor = comment
+           refresh_counter = 0
+           while not ancestor.is_root:
+               ancestor = ancestor.parent()
+               if refresh_counter % 9 == 0:
+                   ancestor.refresh()
+               refresh_counter += 1
+           print('Top-most Ancestor: {}'.format(ancestor))
+
+        The above code should result in 5 network requests to Reddit. Without
+        the calls to :meth:`.refresh` it would make at least 31 network
+        requests.
+
         """
         # pylint: disable=no-member
         if self.parent_id == self.submission.fullname:
             return self.submission
 
-        if '_comments' in self.submission.__dict__ \
-           and self.parent_id in self.submission._comments_by_id:
+        if self.parent_id in self.submission._comments_by_id:
             # The Comment already exists, so simply return it
             return self.submission._comments_by_id[self.parent_id]
         # pylint: enable=no-member
@@ -121,27 +161,6 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
         parent._submission = self.submission
         return parent
 
-    def permalink(self, fast=False):
-        """Return a permalink to the comment.
-
-        :param fast: Return the result as quickly as possible (default: False).
-
-        In order to determine the full permalink for a comment, the Submission
-        may need to be fetched if it hasn't been already. Set ``fast=True`` if
-        you want to bypass that possible load.
-
-        A full permalink looks like:
-        /r/redditdev/comments/2gmzqe/praw_https_enabled/cklhv0f
-
-        A fast-loaded permalink for the same comment will look like:
-        /comments/2gmzqe//cklhv0f
-
-        """
-        # pylint: disable=no-member
-        if not fast or 'permalink' in self.submission.__dict__:
-            return urljoin(self.submission.permalink, self.id)
-        return '/comments/{}//{}'.format(self.submission.id, self.id)
-
     def refresh(self):
         """Refresh the comment's attributes.
 
@@ -155,16 +174,29 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
             comment_path = '{}_/{}'.format(
                 self.submission._info_path(),  # pylint: disable=no-member
                 self.id)
-        comment_list = self._reddit.get(comment_path)[1].children
+
+        # The context limit appears to be 8, but let's ask for more anyway.
+        comment_list = self._reddit.get(comment_path,
+                                        params={'context': 100})[1].children
         if not comment_list:
-            raise ClientException('Comment has been deleted')
-        comment = comment_list[0]
+            raise ClientException(self.MISSING_COMMENT_MESSAGE)
+
+        # With context, the comment may be nested so we have to find it
+        comment = None
+        queue = comment_list[:]
+        while queue and (comment is None or comment.id != self.id):
+            comment = queue.pop()
+            if isinstance(comment, Comment):
+                queue.extend(comment._replies)
+
+        if comment.id != self.id:
+            raise ClientException(self.MISSING_COMMENT_MESSAGE)
 
         if self._submission is not None:
             del comment.__dict__['_submission']  # Don't replace if set
         self.__dict__.update(comment.__dict__)
 
-        for reply in comment._replies:
+        for reply in comment_list:
             reply.submission = self.submission
         return self
 
